"""Task-specific heads for AutoTimm."""

from autotimm.heads._heads import (
    ASPP,
    ClassificationHead,
    DeepLabV3PlusHead,
    DetectionHead,
    FCNHead,
    FPN,
    MaskHead,
    ScaleModule,
    YOLOXHead,
)

__all__ = [
    "ASPP",
    "ClassificationHead",
    "DeepLabV3PlusHead",
    "DetectionHead",
    "FCNHead",
    "FPN",
    "MaskHead",
    "ScaleModule",
    "YOLOXHead",
]
